@@ -9,6 +9,8 @@
 */
 
 #include "eventview_p.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "prefs.h"
 
 #include <CalendarSupport/CollectionSelection>
@@ -100,7 +102,7 @@ void EventView::setHolidayRegions(const QStringList &regions)
 
 int EventView::showMoveRecurDialog(const Incidence::Ptr &inc, QDate date)
 {
-    QDateTime dateTime(date, {}, Qt::LocalTime);
+    QDateTime dateTime(date, {}, QTimeZone::LocalTime);
 
     int availableOccurrences = KCalUtils::RecurrenceActions::availableOccurrences(inc, dateTime);
 
@@ -556,7 +558,7 @@ void EventView::restoreConfig(const KConfigGroup &configGroup)
 
             d->setUpModels();
         }
-        const KConfigGroup selectionGroup = configGroup.config()->group(configGroup.name() + QLatin1String("_selectionSetup"));
+        const KConfigGroup selectionGroup = configGroup.config()->group(configGroup.name() + "_selectionSetup"_L1);
 
         KViewStateMaintainer<ETMViewStateSaver> maintainer(selectionGroup);
         maintainer.setSelectionModel(d->collectionSelectionModel->selectionModel());
@@ -572,7 +574,7 @@ void EventView::saveConfig(KConfigGroup &configGroup)
     configGroup.writeEntry("UseCustomCollectionSelection", d->collectionSelectionModel != nullptr);
 
     if (d->collectionSelectionModel) {
-        KConfigGroup selectionGroup = configGroup.config()->group(configGroup.name() + QLatin1String("_selectionSetup"));
+        KConfigGroup selectionGroup = configGroup.config()->group(configGroup.name() + "_selectionSetup"_L1);
 
         KViewStateMaintainer<ETMViewStateSaver> maintainer(selectionGroup);
         maintainer.setSelectionModel(d->collectionSelectionModel->selectionModel());
@@ -659,13 +661,11 @@ QList<Akonadi::CollectionCalendar::Ptr> EventView::calendars() const
 
 Akonadi::CollectionCalendar::Ptr EventView::calendar3(const Akonadi::Item &item) const
 {
-    Q_D(const EventView);
     return calendarForCollection(item.storageCollectionId());
 }
 
 Akonadi::CollectionCalendar::Ptr EventView::calendar3(const KCalendarCore::Incidence::Ptr &incidence) const
 {
-    Q_D(const EventView);
     const auto collectionId = incidence->customProperty("VOLATILE", "COLLECTION-ID").toLongLong();
     return calendarForCollection(collectionId);
 }
